==> native-ui-0.34.1.tgz: package/lib/components/cta/QuickAction/QuickActionButton/index.js <==
import React from "react";
import { TouchableOpacity } from "react-native";
import Text from "../../../Text";
import baseStyled from "../../../styled";
export const StyledText = baseStyled(Text) `
  overflow: hidden;
  max-width: 100%;
`;
export const Base = baseStyled(TouchableOpacity) `
  height: ${({ variant }) => (variant === "small" ? 59 : 80)}px;
  flex-direction: column;
  text-align: center;
  align-items: center;
  justify-content: center;
  border-radius: ${({ isActive, theme }) => (isActive ? 14 : theme.radii[2])}px;
  padding: ${({ theme, variant }) => variant === "small" ? `${theme.space[3]}px ${theme.space[2]}px` : `0 ${theme.space[6]}px`};
  ${({ visuallyDisabled, isActive, theme }) => {
    if (visuallyDisabled) {
        return `border: 1px solid ${theme.colors.neutral.c30};`;
    }
    else if (isActive) {
        return `background-color: ${theme.colors.neutral.c40};`;
    }
    else {
        return `background-color: ${theme.colors.neutral.c20};`;
    }
}}
`;
const QuickActionButton = ({ Icon, children, disabled, onPress, onPressWhenDisabled, textVariant = "body", variant = "large", testID, isActive = true, ...otherProps }) => {
    const text = // Extract the text to use it as a testID
     React.isValidElement(children) && children.props?.i18nKey
        ? children.props.i18nKey.split(".").pop() // Extract the last part of the key
        : children?.toString().toLowerCase();
    return (React.createElement(Base, { disabled: onPressWhenDisabled ? false : disabled, onPress: disabled ? onPressWhenDisabled : onPress, visuallyDisabled: disabled, variant: variant, isActive: !disabled && isActive, ...otherProps, testID: `${testID}-${text}` },
        React.createElement(Icon, { size: variant === "small" ? 20 : 24, color: disabled ? "neutral.c50" : "neutral.c100" }),
        React.createElement(StyledText, { numberOfLines: 1, variant: textVariant, fontWeight: "semiBold", color: disabled ? "neutral.c50" : "neutral.c100", mt: 2 }, children)));
};
export default QuickActionButton;

==> native-ui-0.38.0.tgz: package/lib/components/cta/QuickAction/QuickActionButton/index.js <==
import React from "react";
import { TouchableOpacity } from "react-native";
import Text from "../../../Text";
import baseStyled from "../../../styled";
export const StyledText = baseStyled(Text) `
  overflow: hidden;
  max-width: 100%;
`;
export const Base = baseStyled(TouchableOpacity) `
  height: ${({ variant }) => (variant === "small" ? 59 : 80)}px;
  flex-direction: column;
  text-align: center;
  align-items: center;
  justify-content: center;
  border-radius: ${({ isActive, theme }) => (isActive ? 14 : theme.radii[2])}px;
  padding: ${({ theme, variant }) => variant === "small" ? `${theme.space[3]}px ${theme.space[2]}px` : `0 ${theme.space[6]}px`};
  ${({ visuallyDisabled, isActive, theme }) => {
    if (visuallyDisabled) {
        return `border: 1px solid ${theme.colors.neutral.c30};`;
    }
    else if (isActive) {
        return `background-color: ${theme.colors.neutral.c40};`;
    }
    else {
        return `background-color: ${theme.colors.neutral.c20};`;
    }
}}
`;
const QuickActionButton = ({ Icon, children, disabled, onPress, onPressWhenDisabled, textVariant = "body", variant = "large", testID, isActive = true, ...otherProps }) => {
    const text = // Extract the text to use it as a testID
     React.isValidElement(children) && children.props?.i18nKey
        ? children.props.i18nKey.split(".").pop() // Extract the last part of the key
        : children?.toString().toLowerCase();
    return (React.createElement(Base, { disabled: onPressWhenDisabled ? false : disabled, onPress: disabled ? onPressWhenDisabled : onPress, visuallyDisabled: disabled, variant: variant, isActive: isActive, ...otherProps, testID: `${testID}-${text}` },
        React.createElement(Icon, { size: variant === "small" ? 20 : 24, color: disabled ? "neutral.c50" : "neutral.c100" }),
        React.createElement(StyledText, { numberOfLines: 1, variant: textVariant, fontWeight: "semiBold", color: disabled ? "neutral.c50" : "neutral.c100", mt: 2 }, children)));
};
export default QuickActionButton;
